@@ -13,22 +13,21 @@
 
 import json
 import logging
+from unittest import mock
 
 import ddt
 import fixtures
 from keystoneauth1 import adapter
 from keystoneauth1 import exceptions as keystone_exception
-import mock
 from oslo_serialization import jsonutils
 import six
 
 from cinderclient import api_versions
 import cinderclient.client
 from cinderclient import exceptions
-import cinderclient.v2.client
-
 from cinderclient.tests.unit import utils
 from cinderclient.tests.unit.v3 import fakes
+import cinderclient.v2.client
 
 
 @ddt.ddt
@@ -49,10 +48,10 @@ class ClientTest(utils.TestCase):
         os_endpoint = 'http://example.com/'
         httpclient_mock.return_value = None
         cinderclient.client._construct_http_client(
-            bypass_url=os_endpoint)
+            os_endpoint=os_endpoint)
         self.assertTrue(httpclient_mock.called)
         self.assertEqual(os_endpoint,
-                         httpclient_mock.call_args[1].get('bypass_url'))
+                         httpclient_mock.call_args[1].get('os_endpoint'))
         session_mock.assert_not_called()
 
     def test_log_req(self):
